Hi,

there are a few occurrences of "chained" misspelt as "chaned" both in comments 
and a log message (found while trying to write a log parser). wpkg-typos.diff 
fixes this.

when using the sendStatus option, the status message during installation is 
"Install: verifying package ...".  This maybe somewhat confusing to users if 
the "verification" takes some time.  a suggestion to improve this situation at 
the expense of losing the processed/total package counter during installation 
is attached as wpkg-status.diff

regards,
malte
--- wpkg.js	2009-07-09 14:58:06.000000000 +0200
+++ wpkg.js	2009-07-09 14:57:07.000000000 +0200
@@ -3113,6 +3113,7 @@
 
 			// print event log entry
 			info("Installing '" + packageName + "' (" + packageID + ")...");
+			logStatus("Installing '" + packageName + " " + (packageRev != 0 ? packageRev + "'" : "'"));
 
 			// stores if the package needs a reboot after installation
 			var rebootRequired = false;
-------------------------------------------------------------------------
wpkg-users mailing list archives >> http://lists.wpkg.org/pipermail/wpkg-users/
_______________________________________________
wpkg-users mailing list
wpkg-users@lists.wpkg.org
http://lists.wpkg.org/mailman/listinfo/wpkg-users

Reply via email to
--- wpkg.js	2009-07-06 12:37:50.000000000 +0200
+++ wpkg.js	2009-07-09 14:58:06.000000000 +0200
@@ -655,7 +655,7 @@
 function checkCondition(checkNode) {
 	var shell = new ActiveXObject("WScript.Shell");
 
-	// geet attributes of check
+	// get attributes of check
 	var checkType = checkNode.getAttribute("type");
 	// Sanity check: must have Type set here.
 	if (checkType == null) {
@@ -1865,7 +1865,7 @@
  * @param packageNode the package node to read the list of chained packages
  *                    from
  * @param packageList optional reference to an array which is used to insert
  *                    the chaned packages to. Specify null to create a new
  *                    Array
  * @return Array specified in packageList parameter extended by package IDs
  *         (string values) which represent the chained packages
@@ -2630,7 +2630,7 @@
 		var profilePackageNodes = new Array();
 
 		/* get package IDs which apply to the profile (without dependencies,
 		 * includes and chaned packages) regardless if the package definition
 		 * is available or not.
 		 */
 		var packageIDs = getProfilePackageIDs();
@@ -3258,7 +3258,7 @@
 
 				} else {
 					info(packageMessage +
-					"Package installed but at least one chaned package failed to install.");
+					"Package installed but at least one chained package failed to install.");
 				}
 				
 				// Reboot the system if needed.
@@ -1865,7 +1865,7 @@
  *                    from
  * @param packageList optional reference to an array which is used to insert
- *                    the chaned packages to. Specify null to create a new
+ *                    the chained packages to. Specify null to create a new
  *                    Array
  * @return Array specified in packageList parameter extended by package IDs
@@ -2630,7 +2630,7 @@
 
 		/* get package IDs which apply to the profile (without dependencies,
-		 * includes and chaned packages) regardless if the package definition
+		 * includes and chained packages) regardless if the package definition
 		 * is available or not.
 		 */